aboutsummaryrefslogtreecommitdiffstats
path: root/include/llvm/Target/DarwinTargetAsmInfo.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/llvm/Target/DarwinTargetAsmInfo.h')
-rw-r--r--include/llvm/Target/DarwinTargetAsmInfo.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/include/llvm/Target/DarwinTargetAsmInfo.h b/include/llvm/Target/DarwinTargetAsmInfo.h
index 0834390..a91a0dd 100644
--- a/include/llvm/Target/DarwinTargetAsmInfo.h
+++ b/include/llvm/Target/DarwinTargetAsmInfo.h
@@ -1,4 +1,4 @@
//===---- DarwinTargetAsmInfo.h - Darwin asm properties ---------*- C++ -*-===//
//
// The LLVM Compiler Infrastructure
//
@@ -15,7 +15,7 @@
#ifndef LLVM_DARWIN_TARGET_ASM_INFO_H
#define LLVM_DARWIN_TARGET_ASM_INFO_H
-#include "llvm/Target/TargetAsmInfo.h"
+#include "llvm/MC/MCAsmInfo.h"
namespace llvm {
class GlobalValue;
@@ -23,8 +23,8 @@ namespace llvm {
class Type;
class Mangler;
- struct DarwinTargetAsmInfo : public TargetAsmInfo {
- explicit DarwinTargetAsmInfo();
+ struct DarwinMCAsmInfo : public MCAsmInfo {
+ explicit DarwinMCAsmInfo();
};
}
@@ -1,4 +1,4 @@
-//===---- DarwinTargetAsmInfo.h - Darwin asm properties ---------*- C++ -*-===//
+//===---- DarwinMCAsmInfo.h - Darwin asm properties -------------*- C++ -*-===//
//
// The LLVM Compiler Infrastructure